"""Simulation of a racquetball game"""

from random import random


def main():
    print_introduction()
    probability_a_wins, probability_b_wins, n = get_inputs()
    games_won_a, games_won_b = simulate_n_games(n, probability_a_wins, probability_b_wins)
    print_summary(games_won_a, games_won_b)


def print_introduction():
    print('This program simulates a game of racquetball between two')
    print('players called A and B.  The abilities of each player is')
    print('indicated by a probability (a number between 0 and 1) that')
    print('the player wins the point when serving. Player A always')
    print('has the first serve.')


def get_inputs():
    a_win_probability = float(input('What is the probability that player A wins a serve? '))
    b_win_probability = float(input('What is the probability that player B wins a serve? '))
    n = int(input('How many games to simulate? '))
    return a_win_probability, b_win_probability, n


def simulate_n_games(n, a_win_probability, b_win_probability):
    wins_a = 0
    wins_b = 0
    for i in range(n):
        score_a, score_b = simulate_one_game(a_win_probability, b_win_probability)
        if score_a > score_b:
            wins_a += 1
        else:
            wins_b += 1
    return wins_a, wins_b


def simulate_one_game(win_probability_a, win_probability_b):
    serving = 'A'
    score_a = 0
    score_b = 0
    while not is_game_over(score_a, score_b):
        if serving == 'A':
            if random() < win_probability_a:
                score_a += 1
            else:
                serving = 'B'
        else:
            if random() < win_probability_b:
                score_b += 1
            else:
                serving = 'A'
    return score_a, score_b


def is_game_over(a_score, b_score):
    return a_score == 15 or b_score == 15


def print_summary(wins_a, wins_b):
    n = wins_a + wins_b
    print(f'\nGames simulated: {n:0,}')
    print(f'Wins for A: {wins_a:0,} ({wins_a / n:0.1%})')
    print(f'Wins for B: {wins_b:0,} ({wins_b / n:0.1%})')


if __name__ == '__main__':
    main()
